aboutsummaryrefslogtreecommitdiff
path: root/build2/c
diff options
context:
space:
mode:
Diffstat (limited to 'build2/c')
-rw-r--r--build2/c/init.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/build2/c/init.cxx b/build2/c/init.cxx
index 88f0b2b..fa17227 100644
--- a/build2/c/init.cxx
+++ b/build2/c/init.cxx
@@ -103,10 +103,10 @@ namespace build2
if (first)
{
// Load cc.vars so that we can cache all the cc.* variables.
//
- if (!cast_false<bool> (b["cc.vars.loaded"]))
- load_module ("cc.vars", r, b, loc);
+ if (!cast_false<bool> (b["cc.core.vars.loaded"]))
+ load_module ("cc.core.vars", r, b, loc);
// Enter all the variables and initialize the module data.
//
@@ -103,10 +103,10 @@ namespace build2
if (first)
{
- // Load cc.vars so that we can cache all the cc.* variables.
+ // Load cc.core.vars so that we can cache all the cc.* variables.
//